﻿using System;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Threading;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;

using GamesStore.Web.Helpers;

namespace GamesStore.Web.Controllers
{
    public class CultureController : Controller
    {
        private class ParsedUrl
        {
            public RouteData RouteData { get; set; }
            public string QueryString { get; set; }
            public Uri Url { get; set; }
        }


        [HttpGet]
        public ActionResult Switch(string cultureCode, string returnUrl)
        {
            var culture = CultureHelper.GetSupportedCulture(cultureCode);

            var parsedUrl = ParseUrl(returnUrl);

            var routeData = parsedUrl.RouteData;
            routeData.Values["Culture"] = culture.ToString();

            var newUrl = Url.Action(routeData.Values["action"] as string, routeData.Values["controller"] as string, routeData.Values);
            if (parsedUrl.QueryString != null)
            {
                newUrl += "?" + parsedUrl.QueryString;
            }
            return Redirect(newUrl);
        }


        public ActionResult CultureHeaderPartial()
        {
            var otherCultures = CultureHelper.SupportedCultures.Where(c => !c.Equals(Thread.CurrentThread.CurrentUICulture));
            return PartialView("_ChangeCultureHeader", otherCultures);
        }


        [HttpGet]
        public ActionResult LoginRedirect(string returnUrl)
        {
            var parsedUrl = ParseUrl(returnUrl);
            var culture = new CultureInfo(parsedUrl.RouteData.Values["culture"] as string);
            return RedirectToAction("Login", "Account", new { Culture = culture.ToString(), ReturnUrl = returnUrl });
        }


        private ParsedUrl ParseUrl(string redirectUrl)
        {
            var questionMarkIndex = redirectUrl.IndexOf('?');
            string queryString = null;
            string url = redirectUrl;
            if (questionMarkIndex != -1)
            {
                url = redirectUrl.Substring(0, questionMarkIndex);
                queryString = redirectUrl.Substring(questionMarkIndex + 1);
            }

            var builder = new UriBuilder(Request.Url);
            builder.Path = url;

            var request = new HttpRequest(null, builder.Uri.ToString(), queryString);
            var response = new HttpResponse(new StringWriter());
            var httpContext = new HttpContext(request, response);

            var routeData = RouteTable.Routes.GetRouteData(new HttpContextWrapper(httpContext));

            return new ParsedUrl
            {
                RouteData = routeData,
                QueryString = queryString,
                Url = request.Url,
            };
        }
    }
}