namespace GamesStore.Web.DataProviders.GamesDbMigrations
{
    using System;
    using System.Data.Entity.Migrations;
    using Entities;
    using Microsoft.AspNet.Identity.EntityFramework;
    using Microsoft.AspNet.Identity;

    internal sealed class GamesDbConfiguration : DbMigrationsConfiguration<GamesDbContext>
    {
        public GamesDbConfiguration()
        {
            AutomaticMigrationsEnabled = true;
            AutomaticMigrationDataLossAllowed = true;
            MigrationsDirectory = @"DataProviders/GamesDbMigrations";
        }

        protected override void Seed(GamesDbContext context)
        {
            var user = new User
            {
                UserName = "Slavo"
            };

            var userManager = new ApplicationUserManager(new UserStore<User>(context));

            userManager.Create(user, "test123");

            var games = new[]
            {
                new Game()
                {
                    Id = Guid.NewGuid(),
                    Name = "Super Mario Bros.",
                    Genre = GameGenreEnum.Action,
                    PublishedOn = new DateTime(1985, 9, 13)
                },
                new Game() {
                    Id = Guid.NewGuid(),
                    Name = "The Secret of Monkey Island",
                    Genre = GameGenreEnum.Adventure,
                    PublishedOn = new DateTime(1990, 10, 1)
                },
                new Game()
                {
                    Id = Guid.NewGuid(),
                    Name = "Plants vs. Zombies",
                    Genre = GameGenreEnum.Arcade,
                    PublishedOn = new DateTime(2009, 5, 5),
                },
                new Game()
                {
                    Id = Guid.NewGuid(),
                    Name = "Wolfenstein 3D",
                    Genre = GameGenreEnum.FirstPersonShooter,
                    PublishedOn = new DateTime(1992, 5, 5),
                },
                new Game()
                {
                    Id = Guid.NewGuid(),
                    Name = "Wolfenstein: The Old Blood",
                    Genre = GameGenreEnum.FirstPersonShooter,
                }
            };

            context.Games.AddOrUpdate(x => x.Name, games);

            context.Studios.AddOrUpdate(
                x => x.Name,
                new Studio()
                {
                    Id = Guid.NewGuid(),
                    Name = "Nintendo Forever",
                    FoundationYear = 1970,
                    Games =
                    {
                        games[0],
                        games[1]
                    }
                },
                new Studio()
                {
                    Id = Guid.NewGuid(),
                    Name = "Kill 'em all",
                    FoundationYear = 2000,
                    Games =
                    {
                        games[2],
                        games[3],
                        games[4]
                    }
                });
        }
    }
}
