﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

using GamesStore.Entities;
using GamesStore.Resources.Games;

namespace GamesStore.Web.Models.Games
{
    public class GameWithoutIdViewModel : IValidatableObject
    {
        [Required(ErrorMessageResourceName = "Title", ErrorMessageResourceType = typeof(GamesStrings))]
        [Display(Name = "Title", ResourceType = typeof(GamesStrings))]
        public string Name { get; set; }

        [DataType(DataType.Date, ErrorMessageResourceName = "PublishedOnInvalid", ErrorMessageResourceType = typeof(GamesStrings))]
        [Display(Name = "Published", ResourceType = typeof(GamesStrings))]
        public DateTime? PublishedOn { get; set; }

        [Display(Name = "Genre", ResourceType = typeof(GamesStrings))]
        [EnumDataType(typeof(GameGenreEnum), ErrorMessageResourceName = "GenreInvalid", ErrorMessageResourceType = typeof(GamesStrings))]
        public GameGenreEnum Genre { get; set; }

        public IEnumerable<ValidationResult> Validate(ValidationContext validationContext)
        {
            if (PublishedOn.HasValue)
            {
                if (PublishedOn.Value.Year < 1950)
                {
                    yield return new ValidationResult(GamesStrings.YearTooFar);
                }
            }
        }
    }
}